@@ -12,7 +12,7 @@ use English qw/ -no_match_vars /;
 use App::Git::Workflow::Pom;
 use App::Git::Workflow::Command qw/get_options/;
 
-our $VERSION = 0.96004;
+our $VERSION = 0.96005;
 our $workflow = App::Git::Workflow::Pom->new;
 our ($name)   = $PROGRAM_NAME =~ m{^.*/(.*?)$}mxs;
 our %option;
@@ -38,7 +38,7 @@ sub run {
 
     if ( !$self->can($sub_command) ) {
         warn "Unknown sub command '$sub_command'!\n";
-        Pod::Usage::pod2usage( %p2u_extra, -verbose => 1 );
+        App::Git::Workflow::Command::pod2usage( %p2u_extra, -verbose => 1 );
         return 1;
     }
 
@@ -89,7 +89,7 @@ sub do_whos {
 
     if (!$version) {
         warn "No version supplied!\n";
-        Pod::Usage::pod2usage( %p2u_extra, -verbose => 1 );
+        App::Git::Workflow::Command::pod2usage( %p2u_extra, -verbose => 1 );
         return 1;
     }
 
@@ -147,7 +147,7 @@ git-pom - Manage pom.xml file versions
 
 =head1 VERSION
 
-This documentation refers to git-pom version 0.96004
+This documentation refers to git-pom version 0.96005
 
 =head1 SYNOPSIS
 
