@@ -13,7 +13,7 @@ use App::Git::Workflow;
 use App::Git::Workflow::Command qw/get_options/;
 use Carp qw/cluck/;
 
-our $VERSION  = 0.96004;
+our $VERSION  = 0.96005;
 our $workflow = App::Git::Workflow->new;
 our ($name)   = $PROGRAM_NAME =~ m{^.*/(.*?)$}mxs;
 our %option;
@@ -24,6 +24,7 @@ sub run {
     %option = (
         format      => 'test',
         max_history => $workflow->config('workflow.max-history') || 1,
+        branches    => 0,
     );
     get_options(
         \%option,
@@ -69,6 +70,9 @@ sub run {
         return branch_age();
     }
 
+    if ($action eq 'do_show') {
+        $option{branches} = 1;
+    }
     my @releases = $workflow->releases(%option);
 
     if ($option{verbose}) {
@@ -108,7 +112,7 @@ sub do_am_i {
     my (undef, @releases) = @_;
 
     # work out current branch, check that it contains a release branch
-    my $format = q/--format=format:'%H %at <%an>%ae'/;
+    my $format = q/--format=format:%H %at <%an>%ae/;
 
     my $bad = 0;
     for my $release (reverse @releases) {
@@ -152,7 +156,7 @@ sub do_update_me {
 sub branches_contain {
     my @releases = @_;
     my @branches = $workflow->branches('both');
-    my $format = q/--format=format:'%H %at <%an>%ae'/;
+    my $format = q/--format=format:%at <%an>%ae/;
     my @csv;
 
     BRANCH:
@@ -163,7 +167,8 @@ sub branches_contain {
         my ($first, $author, $found, $release);
 
         my ($log) = $workflow->git->log($format, qw/-n 1/, $branch);
-        my ($sha, $time, $user) = split /\s+/, $log, 3;
+        next if !$log;
+        my ($time, $user) = split /\s+/, $log, 2;
 
         $first  = $time;
         $author = $user;
@@ -196,13 +201,14 @@ sub branches_contain {
 sub format_text {
     my (undef, $csv, @releases) = @_;
 
-    my @max = (0,0);
+    my @max = (0,0,0);
     for my $row (@$csv) {
         $max[0] = length $row->[0] if $max[0] < length $row->[0];
         $max[1] = length $row->[1] if $max[1] < length $row->[1];
+        $max[2] = length $row->[2] if $max[2] < length $row->[2];
     }
     for my $row (@$csv) {
-        printf "%$max[0]s %$max[1]s %s (%.0f days old)\n", @$row[0..3];
+        printf "%$max[0]s %-$max[1]s %-$max[2]s (%2.0f days old)\n", @$row[0..3];
     }
 
     return;
@@ -299,7 +305,7 @@ git-up-to-date - Check that git branches include latest production branch/tag
 
 =head1 VERSION
 
-This documentation refers to git-up-to-date version 0.96004
+This documentation refers to git-up-to-date version 0.96005
 
 =head1 SYNOPSIS
 
