@@ -12,7 +12,7 @@ use English qw/ -no_match_vars /;
 use App::Git::Workflow;
 use App::Git::Workflow::Command qw/get_options/;
 
-our $VERSION  = 0.96004;
+our $VERSION  = 0.96005;
 our $workflow = App::Git::Workflow->new;
 our ($name)   = $PROGRAM_NAME =~ m{^.*/(.*?)$}mxs;
 our %option;
@@ -47,43 +47,45 @@ sub run {
     my ($last) = git_state();
 
     while ($once) {
-        my ($id, @rest) = git_state();
-        spin() if $option{verbose};
+        eval {
+            my ($id, @rest) = git_state(1);
+            spin() if $option{verbose};
 
-        if ( $last ne $id ) {
-            $once++;
-            my $changes = changes($last, $id, @rest);
+            if ( $last ne $id ) {
+                $once++;
+                my $changes = changes($last, $id, @rest);
 
-            if ( found($changes) ) {
-                if ( $action eq 'show' ) {
-                    my $time = $option{verbose} ? ' @ ' . localtime $changes->{time} : '';
-                    print "$id$time\n";
+                if ( found($changes) ) {
+                    if ( $action eq 'show' ) {
+                        my $time = $option{verbose} ? ' @ ' . localtime $changes->{time} : '';
+                        print "$id$time\n";
 
-                    if ( !$option{quiet} ) {
-                        my $join = $option{verbose} ? "\n    " : '';
-                        print "  Branches: ";
-                        print $join, join +($join || ', '), sort keys %{ $changes->{branches} };
-                        print "\n";
-                        print "  Files:    ";
-                        print $join, join +($join || ', '), sort keys %{ $changes->{files} };
-                        print "\n";
-                        print "  Users:    ";
-                        print $join, join +($join || ', '), sort keys %{ $changes->{user} };
-                        print "\n\n";
+                        if ( !$option{quiet} ) {
+                            my $join = $option{verbose} ? "\n    " : '';
+                            print "  Branches: ";
+                            print $join, join +($join || ', '), sort keys %{ $changes->{branches} };
+                            print "\n";
+                            print "  Files:    ";
+                            print $join, join +($join || ', '), sort keys %{ $changes->{files} };
+                            print "\n";
+                            print "  Users:    ";
+                            print $join, join +($join || ', '), sort keys %{ $changes->{user} };
+                            print "\n\n";
+                        }
+                    }
+                    else {
+                        $ENV{WATCH_SHA}      = $id;
+                        $ENV{WATCH_USERS}    = join ',', keys %{ $changes->{user} };
+                        $ENV{WATCH_EMAILS}   = join ',', keys %{ $changes->{email} };
+                        $ENV{WATCH_FILES}    = join ',', keys %{ $changes->{files} };
+                        $ENV{WATCH_BRANCHES} = join ',', keys %{ $changes->{branches} };
+                        system @ARGV;
                     }
                 }
-                else {
-                    $ENV{WATCH_SHA}      = $id;
-                    $ENV{WATCH_USERS}    = join ',', keys %{ $changes->{user} };
-                    $ENV{WATCH_EMAILS}   = join ',', keys %{ $changes->{email} };
-                    $ENV{WATCH_FILES}    = join ',', keys %{ $changes->{files} };
-                    $ENV{WATCH_BRANCHES} = join ',', keys %{ $changes->{branches} };
-                    system @ARGV;
-                }
             }
-        }
 
-        $last = $id;
+            $last = $id;
+        };
         sleep $option{sleep};
     }
 
@@ -91,14 +93,17 @@ sub run {
 }
 
 sub git_state {
+    my ($fetch) = @_;
     my @out;
 
     if ( $option{all} || $option{remote} ) {
-        $workflow->git->fetch;
+        if ($fetch) {
+            $workflow->git->fetch;
+        }
         @out = $workflow->git->rev_list('--all', "-$option{max}");
     }
     else {
-        $workflow->git->pull(split /\s+/, $option{pull_options}) if $option{pull};
+        $workflow->git->pull(split /\s+/, $option{pull_options}) if $fetch && $option{pull};
         @out = $workflow->git->log('--oneline', "-$option{max}");
     }
 
@@ -167,7 +172,7 @@ git-watch - Watch for changes in repository up-stream
 
 =head1 VERSION
 
-This documentation refers to git-watch version 0.96004
+This documentation refers to git-watch version 0.96005
 
 =head1 SYNOPSIS
 
