@@ -13,7 +13,7 @@ use Data::Dumper qw/Dumper/;
 use English qw/ -no_match_vars /;
 use base qw/Exporter/;
 
-our $VERSION     = 0.96004;
+our $VERSION     = 0.96005;
 our @EXPORT_OK   = qw//;
 our %EXPORT_TAGS = ();
 #our @EXPORT      = qw//;
@@ -36,6 +36,7 @@ sub git {
 
 sub mock_add {
     my $self = shift;
+    confess "Data not Hashes!\n" . Dumper(\@_) if @_ && ref $_[0] ne 'HASH';
     push @{ $self->{data} }, @_;
 }
 sub mock_reset {
@@ -58,7 +59,18 @@ sub AUTOLOAD {
     }
     push @{ $self->{ran} }, $cmd;
 
-    my $return = shift @{ $self->{data} };
+    confess "Data not set up correctly! Not an Array of Hashes\n" if ref $self->{data}[0] ne "HASH";
+    my ($action, $return) = each %{ shift @{ $self->{data} } };
+
+    # sanity check
+    if ($action ne $called) {
+        confess "Expected mock data for '$called' but got data for '$action'!\n"
+            . Dumper($cmd, $return)
+            . "\t# "
+            . (join "\n\t# ", reverse @{ $self->{ran} })
+            . "\n\t";
+    }
+
     if (wantarray) {
         cluck "Returning Mock for `$cmd`\n" . Dumper($return), "\t" if ref $return ne 'ARRAY';
         return @$return;
@@ -79,7 +91,7 @@ Mock::App::Git::Workflow::Repository - Mock of a git repository
 
 =head1 VERSION
 
-This documentation refers to Mock::App::Git::Workflow::Repository version 0.96004
+This documentation refers to Mock::App::Git::Workflow::Repository version 0.96005
 
 =head1 SYNOPSIS
 
